==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/de_DE.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Lade Vorschau…",
    "Saved" : "Gespeichert",
    "Admin" : "Administrator",
    "a safe home for all your data" : "Ein sicheres Zuhause für Ihre Daten",
    "The given name is too long" : "Der eingegebene Name ist zu lang",
    "The given web address is too long" : "Die eingegebene Adresse ist zu lang",
    "The given slogan is too long" : "Der eingegebene Slogan ist zu lang",
    "The given color is invalid" : "Die gewählte Farbe ist ungültig",
    "No file uploaded" : "Keine Datei hochgeladen",
    "Unsupported image type" : "Nicht unterstütztes Bild-Format",
    "You are already using a custom theme" : "Sie benutzen bereits ein eigenes Thema",
    "Theming" : "Theming",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming ermöglicht es auf einfache Weise das Aussehen Ihrer Installation und Clients anzupassen. Die Änderungen wirken sich auf alle Benutzer aus.",
    "Name" : "Name",
    "reset to default" : "Auf Standard zurücksetzen",
    "Web address" : "Internetadresse",
    "Web address https://…" : "Internetadresse https://...",
    "Slogan" : "Slogan",
    "Color" : "Farbe",
    "Logo" : "Logo",
    "Upload new logo" : "Neues Logo hochladen",
    "Login image" : "Anmelde-Bild",
    "Upload new login background" : "Neuen Anmelde-Hintergrund hochladen",
    "Remove background image" : "Entferne Hintergrundbild",
    "Log in image" : "Anmelde-Bild"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/de_DE.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Lade Vorschau…",
    "Saved" : "Gespeichert",
    "Admin" : "Administrator",
    "a safe home for all your data" : "Ein sicheres Zuhause für Ihre Daten",
    "The given name is too long" : "Der eingegebene Name ist zu lang",
    "The given web address is too long" : "Die eingegebene Adresse ist zu lang",
    "The given slogan is too long" : "Der eingegebene Slogan ist zu lang",
    "The given color is invalid" : "Die gewählte Farbe ist ungültig",
    "No file uploaded" : "Keine Datei hochgeladen",
    "Unsupported image type" : "Nicht unterstütztes Bild-Format",
    "You are already using a custom theme" : "Sie benutzen bereits ein eigenes Thema",
    "Theming" : "Theming",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming ermöglicht es auf einfache Weise das Aussehen Ihrer Installation und Clients anzupassen. Die Änderungen wirken sich auf alle Benutzer aus.",
    "Name" : "Name",
    "Reset to default" : " Auf Standard zurücksetzen ",
    "Web address" : "Internetadresse",
    "Web address https://…" : "Internetadresse https://…",
    "Slogan" : "Slogan",
    "Color" : "Farbe",
    "Logo" : "Logo",
    "Upload new logo" : "Neues Logo hochladen",
    "Login image" : "Anmelde-Bild",
    "Upload new login background" : "Neuen Anmelde-Hintergrund hochladen",
    "Remove background image" : "Entferne Hintergrundbild",
    "reset to default" : "Auf Standard zurücksetzen",
    "Log in image" : "Anmelde-Bild"
},
"nplurals=2; plural=(n != 1);");
